* Generic session options - set page and line size, no page breaks;
OPTIONS nonumber nodate nocenter pagesize=MAX linesize=120 formdlim='-';											
* Kill default titles on output; 
TITLE;

* Location for files to be saved - CHANGE THIS TO YOUR DIRECTORY;
%LET example=C:\Dropbox\14_Psyc930MLM\Download\SAS;
LIBNAME example "&example.";
	
* Save SAS syntax and output to permanent text file;
PROC PRINTTO PRINT="&example.\Example1_SAS_Output.txt" 
			 LOG=  "&example.\Example1_SAS_Output.txt"; RUN;

* Open SAS stacked version of ANOVA data into work (temporary) library;
* Centering predictors for analysis;
DATA Example1; SET example.Example1; 
	time1 = time - 1;  * Time was coded 1,2;
	treat = group - 1; * Group was coded 1,2;
	LABEL time1 = "Time (0=pre-test, 1=post-test)"
		  treat = "Treatment Group (0=control, 1=treatment)";
RUN;

TITLE1 "Means by group and time for learning outcome";
PROC MEANS MEAN STDERR MIN MAX DATA=Example1; 
	CLASS group time; 	* Get means per group and time;
	WAYS 0 1 2;  		* Overall, marginal, cell means;
	VAR outcome;		* List variables to describe;
RUN; TITLE1;


TITLE1 "SAS Between-Person Empty Means Model via MIXED";
PROC MIXED DATA=Example1 NOITPRINT NOCLPRINT COVTEST IC METHOD=REML;
	CLASS PersonID time;
	MODEL outcome = / SOLUTION DDFM=BW;
	REPEATED time / R RCORR TYPE=VC SUBJECT=PersonID; 
RUN; TITLE1;

TITLE1 "SAS Within-Person Empty Means Model via MIXED";
PROC MIXED DATA=Example1 NOITPRINT NOCLPRINT COVTEST IC METHOD=REML;
	CLASS PersonID time;
	MODEL outcome = / SOLUTION DDFM=BW;
	REPEATED time / R RCORR TYPE=CS SUBJECT=PersonID;
RUN; TITLE1;

TITLE1 "SAS Between-Person Conditional (Predictor) Model via MIXED";
TITLE2 "Manually dummy coding group and time"; 
PROC MIXED DATA=Example1 NOITPRINT NOCLPRINT COVTEST IC METHOD=REML;
	CLASS PersonID time;
	MODEL outcome = time1 treat time1*treat / SOLUTION DDFM=BW;
	REPEATED time / R RCORR TYPE=VC SUBJECT=PersonID; 
* Request cell means;
	ESTIMATE "Mean: Control Group at Pre-Test"		intercept 1 time1 0 treat 0 time1*treat 0;
	ESTIMATE "Mean: Control Group at Post-Test"		intercept 1 time1 1 treat 0 time1*treat 0;
	ESTIMATE "Mean: Treatment Group at Pre-Test"	intercept 1 time1 0 treat 1 time1*treat 0;
	ESTIMATE "Mean: Treatment Group at Post-Test"	intercept 1 time1 1 treat 1 time1*treat 1;
* Request simple slopes;
	ESTIMATE "Time Effect for Control Group" 		time1 1 time1*treat 0;
	ESTIMATE "Time Effect for Treatment Group" 		time1 1 time1*treat 1;
	ESTIMATE "Group Effect at Pre-Test" 			treat 1 time1*treat 0;
	ESTIMATE "Group Effect at Post-Test" 			treat 1 time1*treat 1;
RUN; TITLE1; TITLE2;

TITLE1 "SAS Within-Person Conditional (Predictor) Model via MIXED";
TITLE2 "Manually dummy coding group and time";
PROC MIXED DATA=Example1 NOITPRINT NOCLPRINT COVTEST IC METHOD=REML;
	CLASS PersonID time;
	MODEL outcome = time1 treat time1*treat / SOLUTION DDFM=BW;
	REPEATED time / R RCORR TYPE=CS SUBJECT=PersonID;
* Request cell means;
	ESTIMATE "Mean: Control Group at Pre-Test"		intercept 1 time1 0 treat 0 time1*treat 0;
	ESTIMATE "Mean: Control Group at Post-Test"		intercept 1 time1 1 treat 0 time1*treat 0;
	ESTIMATE "Mean: Treatment Group at Pre-Test"	intercept 1 time1 0 treat 1 time1*treat 0;
	ESTIMATE "Mean: Treatment Group at Post-Test"	intercept 1 time1 1 treat 1 time1*treat 1;
* Request simple slopes;
	ESTIMATE "Time Effect for Control Group" 	time1 1 time1*treat 0;
	ESTIMATE "Time Effect for Treatment Group" 	time1 1 time1*treat 1;
	ESTIMATE "Group Effect at Pre-Test" 		treat 1 time1*treat 0;
	ESTIMATE "Group Effect at Post-Test" 		treat 1 time1*treat 1;
RUN; TITLE1; TITLE2;

* Close output;
PROC PRINTTO; RUN;
