* Generic session options - page and line size, no page breaks;
OPTIONS nonumber nodate nocenter pagesize=MAX linesize=100 formdlim='-';											
* Kill default titles on output; 
TITLE; 

* Location for original SAS files for these models;
%LET example = C:\Dropbox\14_Psyc930MLM\Download\SAS;
LIBNAME example "&example.";
	
* Bring in SAS file with macro programs;
%INCLUDE "&example.\MLM_Macros.sas";

* Save SAS syntax and output to permanent text file;
PROC PRINTTO PRINT="&example.\Example4_SAS_Output.txt" 
			 LOG=  "&example.\Example4_SAS_Output.txt"; RUN;


******************************************************************************
****** 						EXAMPLE 4 MODELS							******
******************************************************************************;

*** Note: These models assume a stacked data structure in which each row
    provides the response time for a single subject and a single item;

* SAS: Bringing in data from folder to work library;
* Adding another version of predictors to be coded 0/1 for low/high;
DATA Example4; SET example.Example4; 
	IF freq=-.5 THEN freq01=0; IF freq=.5 THEN freq01=1;
	IF size=-.5 THEN size01=0; IF size=.5 THEN size01=1;
run;
TITLE1 "Crosstabs for item types";
PROC FREQ DATA=Example4; TABLE freq01*size01; RUN; TITLE1;

TITLE1 "SAS Empty Means Model: No Random Intercepts (E only)";
PROC MIXED DATA=Example4 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=REML;
	CLASS Subject Item;
	MODEL rt = / SOLUTION DDFM=Satterthwaite; 
	ODS OUTPUT InfoCrit=FitEonly; * Save fit for comparison;
RUN; TITLE1;

TITLE1 "SAS Random Intercept for Subjects Model";
PROC MIXED DATA=Example4 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=REML;
	CLASS Subject Item;
	MODEL rt = / SOLUTION DDFM=Satterthwaite;
	RANDOM INTERCEPT /SUBJECT=Subject TYPE=UN;  * Level 2 variance for subjects;
	ODS OUTPUT InfoCrit=FitRandSubjects; * Save fit for comparison;
RUN; TITLE1;
* Calculate difference in model fit relative to e-only model;
%FitTest(FitFewer=FitEonly, FitMore=FitRandSubjects);

TITLE1 "SAS Random Intercepts for Subjects and Items: Crossed Model";
PROC MIXED DATA=Example4 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=REML;
	CLASS Subject Item;
	MODEL rt =  / SOLUTION DDFM=Satterthwaite;
	RANDOM INTERCEPT / SUBJECT=Item TYPE=UN; 	* Level 2 variance for items;
	RANDOM INTERCEPT / SUBJECT=Subject TYPE=UN; * Level 2 variance for subjects; 
	ODS OUTPUT InfoCrit=FitRandItems CovParms=CovEmpty; * Save fit, variances to compare;
RUN; TITLE1;
* Calculate difference in model fit relative to random subjects model;
%FitTest(FitFewer=FitRandSubjects, FitMore=FitRandItems);

TITLE1 "SAS Random Subjects by Random Items Crossed Predictive Model";
TITLE2 "Using CLASS statement to get cell means and comparisons VIA LSMEANS";
PROC MIXED DATA=Example4 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=REML;
	* Add freq and size to CLASS statement to use LSMEANS;
	CLASS Subject Item freq01 size01;
	* | operator estimates all possible main effects and interactions up to @ order;
	MODEL rt = freq01|size01@2 / SOLUTION DDFM=Satterthwaite OUTPM=ItemPred;
	RANDOM INTERCEPT / SUBJECT=Item TYPE=UN; 	* Level 2 variance for items;
	RANDOM INTERCEPT / SUBJECT=Subject TYPE=UN; * Level 2 variance for subjects; 
	ODS OUTPUT InfoCrit=FitRandItem CovParms=CovItemPred; * Save fit, variances to compare;
	* Requesting marginal means per condition (what Type 3 tests are for);
	LSMEANS freq01 size01; 
	* Requesting F-tests for simple main effects (more useful than marginal);
	LSMEANS freq01*size01 / SLICE=freq01 SLICE=size01;
RUN; TITLE1; TITLE2;
* Get total R2;
PROC CORR DATA=ItemPred; VAR pred rt; RUN;
* Calculate PseudoR2 relative to empty means model;
%PseudoR2(NCov=3, CovFewer=CovEmpty, CovMore=CovItemPred);

TITLE1 "SAS Dropping Random Item Intercept";
PROC MIXED DATA=Example4 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=REML;
	CLASS Subject Item;
	MODEL rt = freq01|size01@2 / SOLUTION DDFM=Satterthwaite;
	RANDOM INTERCEPT / SUBJECT=Subject TYPE=UN; * Level 2 variance for subjects ONLY; 
	ODS OUTPUT InfoCrit=FitNoRandItem;          * Save fit to compare;
RUN; TITLE1;
* Calculate difference in model fit relative to random subjects and items predictive model;
%FitTest(FitFewer=FitNoRandItem, FitMore=FitRandItem);

TITLE1 "SAS Random Slope for Effect of Freq over Subjects";
TITLE2 "Removed Freq and Size from CLASS to fit random slope";
PROC MIXED DATA=Example4 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=REML;
	CLASS Subject Item;
	MODEL rt = freq01|size01@2 / SOLUTION DDFM=Satterthwaite;
	RANDOM INTERCEPT        / SUBJECT=Item TYPE=UN;		* Level 2 variance for items;
	RANDOM INTERCEPT freq01 / SUBJECT=Subject TYPE=UN; 	* Level 2 variances for subjects; 
	ODS OUTPUT InfoCrit=FitRandFreq;         		    * Save fit to compare;
RUN; TITLE1; TITLE2;
* Calculate difference in model fit relative to random subjects and items predictive model;
%FitTest(FitFewer=FitRandItem, FitMore=FitRandFreq);

TITLE1 "SAS Random Slope for Effect of Size over Subjects";
PROC MIXED DATA=Example4 COVTEST NOCLPRINT NOITPRINT NAMELEN=100 IC METHOD=REML;
	CLASS Subject Item;
	MODEL rt = freq01|size01@2 / SOLUTION DDFM=Satterthwaite;
	RANDOM INTERCEPT        / SUBJECT=Item TYPE=UN;		* Level 2 variance for items;
	RANDOM INTERCEPT size01 / SUBJECT=Subject TYPE=UN; 	* Level 2 variances for subjects; 
	ODS OUTPUT InfoCrit=FitRandSize;         		    * Save fit to compare;
RUN; TITLE1; 
* Calculate difference in model fit relative to random subjects and items predictive model;
%FitTest(FitFewer=FitRandItem, FitMore=FitRandSize);

* Close output;
PROC PRINTTO; RUN;
