
* Define locations of files used in examples -- CHANGE THIS.
FILE HANDLE example /NAME = "C:\Dropbox\14_Psyc930MLM\Download\SPSS".

* SPSS code to import data. 
GET FILE = "example/Example23.sav".
DATASET NAME example23 WINDOW=FRONT.

* Center time for polynomial models.
COMPUTE c1sess = Session - 1.
VARIABLE LABELS  c1sess  "c1sess: Session Centered at 1".

	* Create piecewise slopes.
RECODE session (1=0) (2 THRU HI=1) INTO Slope12.
RECODE session (LO THRU 2=0) (3=1) (4=2) (5=3) (6=4) INTO Slope26.
VARIABLE LABELS Slope12 "Slope12: Early Practice Slope (Session 1-2)"
			             Slope26 "Slope26: Later Practice Slope (Session 2-6)". 
EXECUTE.


******************************************************************************
****** 						                 EXAMPLE 2 MODELS							                   ******
******************************************************************************.
DATASET ACTIVATE example23 WINDOW=FRONT.

TITLE "SPSS Model 1a: Empty Means, Random Intercept".
MIXED nm3rt BY ID session
	/METHOD = REML
 /PRINT = SOLUTION TESTCOV G R
 /FIXED = 
 /RANDOM = INTERCEPT | SUBJECT(ID) COVTYPE(UN)
	/REPEATED = session | SUBJECT(ID) COVTYPE(ID).
TITLE.

TITLE "SPSS Model 1b: Saturated Means, Unstructured Variances".
MIXED nm3rt BY ID session
	/METHOD = REML
 /PRINT  = SOLUTION TESTCOV R
 /FIXED  = session
	/REPEATED = session | SUBJECT(ID) COVTYPE(UN)
 /EMMEANS = TABLES(session).
TITLE.

*** POLYNOMIAL MODELS ***.

TITLE "SPSS Model 2a: Fixed Linear Time, Random Intercept ".
MIXED nm3rt BY ID session WITH c1sess
	/METHOD = REML
 /PRINT  = SOLUTION TESTCOV G R
 /FIXED  = c1sess
 /RANDOM = INTERCEPT | SUBJECT(ID) COVTYPE(UN)
	/REPEATED = session | SUBJECT(ID) COVTYPE(ID).
TITLE.

TITLE "SPSS Model 2b: Random Linear Time".
MIXED nm3rt BY ID session WITH c1sess
	/METHOD = REML
	/PRINT  = SOLUTION TESTCOV G R
 /FIXED  = c1sess
	/RANDOM = INTERCEPT c1sess | SUBJECT(ID) COVTYPE(UN)
	/REPEATED = session | SUBJECT(ID) COVTYPE(ID).
TITLE.

TITLE "SPSS Model 3a: Fixed Quadratic, Random Linear Time".
MIXED nm3rt BY ID session WITH c1sess
	/METHOD = REML
 /PRINT  = SOLUTION TESTCOV G R
	/FIXED  = c1sess c1sess*c1sess
	/RANDOM = INTERCEPT c1sess | SUBJECT(ID) COVTYPE(UN)
	/REPEATED = session | SUBJECT(ID) COVTYPE(ID).
TITLE.

TITLE "SPSS Model 3b: Random Quadratic Time".
MIXED nm3rt BY ID session WITH c1sess
	/METHOD = REML
 /PRINT  = SOLUTION TESTCOV G R
 /FIXED  = c1sess c1sess*c1sess
 /RANDOM = INTERCEPT c1sess c1sess*c1sess | SUBJECT(ID) COVTYPE(UN)
	/REPEATED = session | SUBJECT(ID) COVTYPE(ID)
 /TEST = "Intercept at Session 1" 	  intercept 1 c1sess 0   c1sess*c1sess 0
	/TEST = "Intercept at Session 2" 	  intercept 1 c1sess 1   c1sess*c1sess 1
 /TEST = "Intercept at Session 3" 	  intercept 1 c1sess 2   c1sess*c1sess 4
	/TEST = "Intercept at Session 4" 	  intercept 1 c1sess 3   c1sess*c1sess 9
	/TEST = "Intercept at Session 5" 	  intercept 1 c1sess 4   c1sess*c1sess 16
	/TEST = "Intercept at Session 6" 	  intercept 1 c1sess 5   c1sess*c1sess 25
	/TEST = "Linear Slope at Session 1" 	c1sess 1    c1sess*c1sess 0
	/TEST = "Linear Slope at Session 2" 	c1sess 1    c1sess*c1sess 2
	/TEST = "Linear Slope at Session 3" 	c1sess 1    c1sess*c1sess 4
	/TEST = "Linear Slope at Session 4" 	c1sess 1    c1sess*c1sess 6
	/TEST = "Linear Slope at Session 5" 	c1sess 1    c1sess*c1sess 8
	/TEST = "Linear Slope at Session 6" 	c1sess 1    c1sess*c1sess 10.
TITLE.

*** PIECEWISE MODELS ***.

TITLE "SPSS Model 4a: Fixed Slope12, Fixed Slope26, Random Intercept Model".
MIXED nm3rt BY ID session WITH Slope12 Slope26
	/METHOD = REML
	/PRINT  = SOLUTION TESTCOV G R
 /FIXED  = Slope12 Slope26
	/RANDOM = INTERCEPT | SUBJECT(ID) COVTYPE(UN)
	/REPEATED = session | SUBJECT(ID) COVTYPE(ID).
TITLE.

TITLE "SPSS Model 4b: Random Slope12, Fixed Slope26 Model".
MIXED nm3rt BY ID session WITH Slope12 Slope26
	/METHOD = REML
	/PRINT  = SOLUTION TESTCOV G R
 /FIXED  = Slope12 Slope26
	/RANDOM = INTERCEPT Slope12 | SUBJECT(ID) COVTYPE(UN)
	/REPEATED = session | SUBJECT(ID) COVTYPE(ID).
TITLE.

TITLE "SPSS Model 4c: Random Slope12, Random Slope26 Model".
MIXED nm3rt BY ID session WITH Slope12 Slope26
	/METHOD = REMLs
	/PRINT  = SOLUTION TESTCOV G R
 /FIXED  = Slope12 Slope26
	/RANDOM = INTERCEPT Slope12 Slope26 | SUBJECT(ID) COVTYPE(UN)
	/REPEATED = session | SUBJECT(ID) COVTYPE(ID)
	/TEST = "Session 1 Predicted Mean" Intercept 1 Slope12 0 Slope26 0
	/TEST = "Session 2 Predicted Mean" Intercept 1 Slope12 1 Slope26 0
	/TEST = "Session 3 Predicted Mean" Intercept 1 Slope12 1 Slope26 1
	/TEST = "Session 4 Predicted Mean" Intercept 1 Slope12 1 Slope26 2
	/TEST = "Session 5 Predicted Mean" Intercept 1 Slope12 1 Slope26 3
	/TEST = "Session 6 Predicted Mean" Intercept 1 Slope12 1 Slope26 4
	/TEST = "Difference between slopes" Slope12 -1 Slope26 1.
TITLE.

TITLE "SPSS Model 5c: Random Slope16, Random Slope26 Model".
MIXED nm3rt BY ID session WITH c1sess Slope26
	/METHOD = REML
	/PRINT  = SOLUTION TESTCOV G R
 /FIXED  = c1sess Slope26
	/RANDOM = INTERCEPT c1sess Slope26 | SUBJECT(ID) COVTYPE(UN)
	/REPEATED = session | SUBJECT(ID) COVTYPE(ID)
	/TEST = "Slope between sessions 2-6" c1sess 1 Slope26 1.
TITLE.

******************************************************************************
****** 						                 EXAMPLE 3 MODELS							                   ******
******************************************************************************.

* Centering level-2 predictor variables for analysis.
DATASET ACTIVATE example23 WINDOW=FRONT.
COMPUTE age80  = age - 80.
COMPUTE reas22 = absreas - 22.
VARIABLE LABELS 
	age80 "age80: Age Centered (0=80)"
	reas22 "reas22: Abstract Reasoning Centered (0=22)".
* Make education a grouping variable for purpose of demonstration only.
IF educyrs LE 12                   educgrp=1.
IF educyrs GT 12 AND educyrs LE 16 educgrp=2.
IF educyrs GT 16                   educgrp=3.
VARIABLE LABELS educgrp "educgrp: Education Group (1=HS, 2=BA, 3=GRAD)".
* Removing cases with missing predictors. 
SELECT IF (NVALID(age80, reas22, educgrp)=3).
EXECUTE.

TITLE "SPSS Model 3b: Random Quadratic Time Baseline in ML".
MIXED nm3rt BY ID session WITH c1sess
	/METHOD = ML
 /PRINT  = SOLUTION TESTCOV G 
 /FIXED  = c1sess c1sess*c1sess
 /RANDOM = INTERCEPT c1sess c1sess*c1sess | SUBJECT(ID) COVTYPE(UN)
	/REPEATED = session | SUBJECT(ID) COVTYPE(ID)
 /SAVE = FIXPRED (predtime).
CORRELATIONS nm3rt predtime.
TITLE.

TITLE "SPSS Model 4a: Age as Predictor of Intercept, Linear, and Quadratic".
MIXED nm3rt BY ID session WITH c1sess age80
	/METHOD = ML
 /PRINT  = SOLUTION TESTCOV G 
 /FIXED  = c1sess c1sess*c1sess age80 c1sess*age80 c1sess*c1sess*age80
 /RANDOM = INTERCEPT c1sess c1sess*c1sess | SUBJECT(ID) COVTYPE(UN)
	/REPEATED = session | SUBJECT(ID) COVTYPE(ID)
 /SAVE = FIXPRED (predage)
	/TEST = "Age Effect at Session 1" age80 1 c1sess*age80 0 c1sess*c1sess*age80 0
	/TEST = "Age Effect at Session 2" age80 1 c1sess*age80 1 c1sess*c1sess*age80 1
	/TEST = "Age Effect at Session 3" age80 1 c1sess*age80 2 c1sess*c1sess*age80 4
	/TEST = "Age Effect at Session 4" age80 1 c1sess*age80 3 c1sess*c1sess*age80 9
	/TEST = "Age Effect at Session 5" age80 1 c1sess*age80 4 c1sess*c1sess*age80 1
	/TEST = "Age Effect at Session 6" age80 1 c1sess*age80 5 c1sess*c1sess*age80 25. 
CORRELATIONS nm3rt predage.
TITLE.

TITLE "SPSS Model 5a: +Reasoning as Predictor of Intercept, Linear, and Quadratic".
MIXED nm3rt BY ID session WITH c1sess age80 reas22
	/METHOD = ML
 /PRINT  = SOLUTION TESTCOV G 
 /FIXED  = c1sess c1sess*c1sess age80 c1sess*age80 c1sess*c1sess*age80 
           reas22 c1sess*reas22 c1sess*c1sess*reas22 
 /RANDOM = INTERCEPT c1sess c1sess*c1sess | SUBJECT(ID) COVTYPE(UN)
	/REPEATED = session | SUBJECT(ID) COVTYPE(ID)
 /SAVE = FIXPRED (predreas). 
CORRELATIONS nm3rt predreas.
TITLE.

TITLE "SPSS Model 5b: +Reasoning as Predictor of Intercept, Linear Time Slope Only".
MIXED nm3rt BY ID session WITH c1sess age80 reas22
	/METHOD = ML
 /PRINT  = SOLUTION TESTCOV G 
 /FIXED  = c1sess c1sess*c1sess age80 c1sess*age80 c1sess*c1sess*age80 
           reas22 c1sess*reas22 
 /RANDOM = INTERCEPT c1sess c1sess*c1sess | SUBJECT(ID) COVTYPE(UN)
	/REPEATED = session | SUBJECT(ID) COVTYPE(ID)
 /SAVE = FIXPRED (predreas2)
	/TEST = "Reasoning Effect at Session 1" reas22 1 c1sess*reas22 0
	/TEST = "Reasoning Effect at Session 2" reas22 1 c1sess*reas22 1
	/TEST = "Reasoning Effect at Session 3" reas22 1 c1sess*reas22 2
	/TEST = "Reasoning Effect at Session 4" reas22 1 c1sess*reas22 3
	/TEST = "Reasoning Effect at Session 5" reas22 1 c1sess*reas22 4
	/TEST = "Reasoning Effect at Session 6" reas22 1 c1sess*reas22 5.
CORRELATIONS nm3rt predreas2.
TITLE.

TITLE "SPSS Model 6a: +Education Group on Intercept, Linear, and Quadratic".
MIXED nm3rt BY ID session educgrp WITH c1sess age80 reas22
 /METHOD = ML
 /PRINT  = SOLUTION TESTCOV G
 /FIXED  = c1sess c1sess*c1sess age80 c1sess*age80 c1sess*c1sess*age80 
           reas22 c1sess*reas22 educgrp c1sess*educgrp c1sess*c1sess*educgrp
 /RANDOM = INTERCEPT c1sess c1sess*c1sess | SUBJECT(ID) COVTYPE(UN)
	/REPEATED = session | SUBJECT(ID) COVTYPE(ID)
 /SAVE = FIXPRED (prededuc)
	/EMMEANS = TABLES(educgrp) WITH (c1sess=0) COMPARE(educgrp)
	/EMMEANS = TABLES(educgrp) WITH (c1sess=5) COMPARE(educgrp)
	/TEST = "L vs. H Educ for for Main Effect" educgrp -1  0  1
	/TEST = "M vs. H Educ for for Main Effect" educgrp  0 -1  1
	/TEST = "L vs. M Educ for for Main Effect" educgrp -1  1  0
	/TEST = "L vs. H Educ for for Linear Session" c1sess*educgrp -1  0  1
	/TEST = "M vs. H Educ for for Linear Session" c1sess*educgrp  0 -1  1
	/TEST = "L vs. M Educ for for Linear Session" c1sess*educgrp -1  1  0
	/TEST = "L vs. H Educ for for Quadratic Session" c1sess*c1sess*educgrp -1  0  1
	/TEST = "M vs. H Educ for for Quadratic Session" c1sess*c1sess*educgrp  0 -1  1
	/TEST = "L vs. M Educ for for Quadratic Session" c1sess*c1sess*educgrp -1  1  0.
CORRELATIONS nm3rt prededuc.
TITLE.


