********************************************************************************
*******                   EXAMPLE 1: BP AND WP MODELS                     ******
********************************************************************************

 * Open file used in example -- CHANGE THIS
use "C:\Dropbox\14_Psyc930MLM\Download\STATA\Example1.dta", clear

 * Save results to separate file
log using C:\Dropbox\14_Psyc930MLM\Download\STATA\Example1_STATA_Output.log, replace

 * STATA code to center predictors for analysis
gen time1 = time - 1
gen treat = group - 1
label variable time1 "Time (0=pre-test 1=post-test)"
label variable treat "Treatment Group (0=control, 1=treatment)"
 
 * Means by group and time for learning outcome
tabulate group time, summarize(outcome)
 

 * STATA Between-Person Empty Means Model via xtmixed
xtmixed outcome ,  || PersonID:  , noconstant  /// 
	variance reml residuals(independent,t(time))

 * STATA Within-Person Empty Means Model via xtmixed
xtmixed outcome ,  || PersonID:  , noconstant  /// 
	variance reml residuals(exchangeable,t(time))

 * STATA Between-Person Conditional Model via xtmixed
xtmixed outcome c.time1 c.treat c.time1#c.treat, ///
    || PersonID:  , noconstant  /// 
	variance reml residuals(independent,t(time)),
	* Request cell means
	margins, at(c.time1=(0 1) c.treat=(0 1)) vsquish
	* Request simple slopes
	lincom 1*c.time  + 0*c.time#c.treat // time effect for control 
	lincom 1*c.time  + 1*c.time#c.treat // time effect for treat
	lincom 1*c.treat + 0*c.time#c.treat // group effect for pre-test
	lincom 1*c.treat + 1*c.time#c.treat // group effect for post-test

 * STATA Within-Person Conditional Model via xtmixed
xtmixed outcome c.time1 c.treat c.time1#c.treat, ///
    || PersonID:  , noconstant  /// 
	variance reml residuals(exchangeable,t(time)),
	* Request cell means
	margins, at(c.time1=(0 1) c.treat=(0 1)) vsquish
	* Request simple slopes
	lincom 1*c.time  + 0*c.time#c.treat // time effect for control 
	lincom 1*c.time  + 1*c.time#c.treat // time effect for treat
	lincom 1*c.treat + 0*c.time#c.treat // group effect for pre-test
	lincom 1*c.treat + 1*c.time#c.treat // group effect for post-test

 * Close log	
 log close
