
 ******************************************************************************
 ****** 						EXAMPLE 2 MODELS						 ******
 ******************************************************************************

 * Open file used in example -- CHANGE THIS
use "C:\Dropbox\14_Psyc930MLM\Download\STATA\Example23.dta", clear
 
 * Save results to separate file
log using C:\Dropbox\14_Psyc930MLM\Download\STATA\Example2_STATA_Output.log, replace

 * Center time for polynomial models (and make quadratic versions)
gen c1sess = session - 1
label variable c1sess  "c1sess: Session Centered at 1"
gen c1sess2 = c1sess * c1sess
label variable c1sess2 "c1sess2: Quadratic Session Centered at 1"

 * Create piecewise slopes
gen slope12 = session
gen slope26 = session
recode slope12 (1=0) if session==1
recode slope12 (2=1) if session==2
recode slope12 (3=1) if session==3
recode slope12 (4=1) if session==4
recode slope12 (5=1) if session==5
recode slope12 (6=1) if session==6
recode slope26 (1=0) if session==1
recode slope26 (2=0) if session==2
recode slope26 (3=1) if session==3
recode slope26 (4=2) if session==4
recode slope26 (5=3) if session==5
recode slope26 (6=4) if session==6
label variable slope12 "slope12: Early Practice Slope (Session 1-2)"
label variable slope26 "slope26: Later Practice Slope (Session 2-6)"

	
 * STATA Model 1a: Empty Means, Random Intercept
xtmixed nm3rt ,  || id:  ,  /// 
	variance reml covariance(unstructured) residuals(independent,t(session)), 
	estat ic, n(101)
	estat recovariance, level(id)

 * STATA Model 1b: Saturated Means, Unstructured Variance
xtmixed nm3rt ib(last).session, || id: , noconstant /// 
	variance reml residuals(unstructured, t(session)),
	estat ic, n(101),
	contrast session,   // omnibus test of mean differences
	margins i.session,  // observed means per session
	marginsplot, name(saturated_means, replace) // plot observed means  
	
*** POLYNOMIAL MODELS ***	
	
 * STATA Model 2a: Fixed Linear Time, Random Intercept
xtmixed nm3rt c.c1sess,  || id:  ,  /// 
	variance reml covariance(un) residuals(independent,t(session)),  
	estat ic, n(101), 
	estat recovariance, level(id),
	estimates store FixLin

 * STATA Model 2b: Random Linear Time
xtmixed nm3rt c.c1sess,  || id: c1sess,  /// 
	variance reml covariance(un) residuals(independent,t(session)),  
	estat ic, n(101), 
	estat recovariance, level(id),
	estimates store RandLin,
	lrtest RandLin FixLin

 * STATA Model 3a: Fixed Quadratic, Random Linear Time
xtmixed nm3rt c.c1sess c.c1sess#c.c1sess,  || id: c1sess,  /// 
	variance reml covariance(un) residuals(independent,t(session)),  
	estat ic, n(101), 
	estat recovariance, level(id),
	estimates store FixQuad
	
 * STATA Model 3b: Random Quadratic Time
xtmixed nm3rt c.c1sess c.c1sess#c.c1sess,  || id: c1sess c1sess2,  /// 
	variance reml covariance(un) residuals(independent,t(session)),  
	estat ic, n(101), 
	estat recovariance, level(id),
	estimates store RandQuad,
	lrtest RandQuad FixQuad,
	margins, at(c.c1sess=(0(1)5))	vsquish				    // intercepts per session
	marginsplot, name(predicted_means, replace)		   		// plot intercepts
	margins, at(c.c1sess=(0(1)5)) dydx(c.c1sess) vsquish    // linear slope per session
	marginsplot, name(change_in_linear_slope, replace) 		// plot quadratic effect
	
*** PIECEWISE MODELS ***

* STATA Model 4a: Fixed Slope12, Fixed Slope26, Random Intercept Model
xtmixed nm3rt c.slope12 c.slope26,  || id:,  /// 
	variance reml covariance(un) residuals(independent,t(session)),  
	estat ic, n(101), 
	estimates store FixPiece

* STATA Model 4b: Random Slope12, Fixed Slope26 Model
xtmixed nm3rt c.slope12 c.slope26,  || id: slope12,  /// 
	variance reml covariance(un) residuals(independent,t(session)),  
	estat ic, n(101), 
	estat recovariance, level(id),
	estimates store RandP1,
	lrtest RandP1 FixPiece

* STATA Model 4c: Random Slope12, Random Slope26 Model
xtmixed nm3rt c.slope12 c.slope26,  || id: slope12 slope26,  /// 
	variance reml covariance(un) residuals(independent,t(session)),  
	estat ic, n(101), 
	estat recovariance, level(id),
	estimates store RandP2,
	lrtest RandP2 RandP1
	lincom -1*c.slope12 + 1*c.slope26		// difference between slopes

* STATA Model 5c: Random Slope16, Random Slope26 Model
xtmixed nm3rt c.c1sess c.slope26,  || id: c1sess slope26,  /// 
	variance reml covariance(un) residuals(independent,t(session)),  
	estat ic, n(101)
	estat recovariance, level(id),
	lincom 1*c.c1sess + 1*c.slope26		// slope between sessions 2 to 6
	
 * Close log	
 log close
 
 ******************************************************************************
 ****** 						EXAMPLE 3 MODELS						 ******
 ******************************************************************************
 
 * Save results to separate file
log using C:\Dropbox\14_Psyc930MLM\Download\STATA\Example3_STATA_Output.log, replace
 
 * centering level-2 predictor variables for analysis
gen age80 = age - 80
gen reas22 = absreas - 22
label variable age80 "age80: Age Centered (0=80 years)"
label variable reas22 "reas22: Abstract Reasoning Centered (0=22)"
* make education a grouping variable for purpose of demonstration only
gen educgrp=.   
replace educgrp=1 if (educyrs <= 12) 
replace educgrp=2 if (educyrs > 12 & educyrs <= 16)
replace educgrp=3 if (educyrs > 16)
label variable educgrp "educgrp: Education Group (1=HS, 2=BA, 3=GRAD)"

 * create new variable to hold number of missing cases
 * then drop cases with incomplete predictors
egen nummiss = rowmiss(age80 reas22 educgrp)
drop if nummiss>0

 * STATA Model 3b: Random Quadratic Time Baseline in ML
xtmixed nm3rt c.c1sess c.c1sess#c.c1sess,  || id: c1sess c1sess2,  /// 
	variance ml covariance(un) residuals(independent,t(session)),  
	estat ic, n(101), 
	estat recovariance, level(id),
	estimates store Baseline,	// save LL for LRT
	predict predtime			// save fixed-effect predicted outcomes 
corr nm3rt predtime				// get total r to make r2

 * STATA Model 4a: Age as Predictor of Intercept, Linear, and Quadratic
xtmixed nm3rt c.c1sess c.c1sess#c.c1sess   				///
	c.age80 c.age80#c.c1sess c.age80#c.c1sess#c.c1sess, ///
	|| id: c1sess c1sess2, 								/// 
	variance ml covariance(un) residuals(independent,t(session)),  
	estat ic, n(101), 
	estat recovariance, level(id),
	estimates store Age,		// save LL for LRT
	lrtest Age Baseline,		// LRT against non-age baseline
	predict predage				// save fixed-effect predicted outcomes
	margins, at(c.c1sess=(0(1)5)) dydx(c.age80) vsquish    // age slope per session
	margins, at(c.c1sess=(0(1)5) c.age80=(-5 0 5)) vsquish  // predictions per session
	marginsplot, name(predicted_age, replace)		    // plot age predictions
corr nm3rt predage	// get total r to make r2

 * STATA Model 5a: +Reasoning as Predictor of Intercept, Linear, and Quadratic
xtmixed nm3rt c.c1sess c.c1sess#c.c1sess   					///
	c.age80  c.age80#c.c1sess c.age80#c.c1sess#c.c1sess  	///
	c.reas22 c.reas22#c.c1sess c.reas22#c.c1sess#c.c1sess,  ///
	|| id: c1sess c1sess2, 									/// 
	variance ml covariance(un) residuals(independent,t(session)),  
	estat ic, n(101), 
	estat recovariance, level(id),
	estimates store Reas,		// save LL for LRT
	lrtest Reas Age,			// LRT against age baseline
	predict predreas		 	// save fixed-effect predicted outcomes 
corr nm3rt predreas				// get total r to make r2

* STATA Model 5b: +Reasoning as Predictor of Intercept, Linear Time Slope Only 
xtmixed nm3rt c.c1sess c.c1sess#c.c1sess   				 	///
	c.age80  c.age80#c.c1sess c.age80#c.c1sess#c.c1sess  	///
	c.reas22 c.reas22#c.c1sess, || id: c1sess c1sess2,   	/// 
	variance ml covariance(un) residuals(independent,t(session)),  
	estat ic, n(101), 
	estat recovariance, level(id),
	estimates store Reas2,		// save LL for LRT
	lrtest Reas2 Age,			// LRT against age baseline
	margins, at(c.c1sess=(0(1)5)) dydx(c.reas22) vsquish     // reas slope per session
	margins, at(c.c1sess=(0(1)5) c.reas22=(-5 0 5)) vsquish  // predictions per session
	marginsplot, name(predicted_reas, replace)		     // plot reas predictions
	predict predreas2			// save fixed-effect predicted outcomes 
corr nm3rt predreas2			// get total r to make r2

* STATA Model 6a: +Education Group on Intercept, Linear, and Quadratic
xtmixed nm3rt c.c1sess c.c1sess#c.c1sess   				 	///
	c.age80  c.age80#c.c1sess c.age80#c.c1sess#c.c1sess  	///
	c.reas22 c.reas22#c.c1sess    							/// 
	ib(last).educgrp ib(last).educgrp#c.c1sess 				/// 
	ib(last).educgrp#c.c1sess#c.c1sess, || id: c1sess c1sess2,  /// 
	variance ml covariance(un) residuals(independent,t(session)),  
	estat ic, n(101), 
	estat recovariance, level(id),
	estimates store Educ,
	lrtest Educ Reas2,
 * Estimating group means at first and last sessions
 	margins ib(last).educgrp,  at(c1sess=(0))
 	margins ib(last).educgrp,  at(c1sess=(5))
 * Contrasts between groups on intercept, linear, and quadratic slopes
 	test 1.educgrp=3.educgrp				// Low vs. High: Intercept
	test 2.educgrp=3.educgrp				// Med vs. High: Intercept
	test 1.educgrp=2.educgrp				// Low vs. Med:  Intercept
	test 1.educgrp#c.c1sess=3.educgrp#c.c1sess		// Low vs. High: Linear
	test 2.educgrp#c.c1sess=3.educgrp#c.c1sess		// Med vs. High: Linear
	test 1.educgrp#c.c1sess=2.educgrp#c.c1sess		// Low vs. Med:  Linear
	test 1.educgrp#c.c1sess#c.c1sess=3.educgrp#c.c1sess#c.c1sess  // Low vs. High: Quad
	test 2.educgrp#c.c1sess#c.c1sess=3.educgrp#c.c1sess#c.c1sess  // Med vs. High: Quad
	test 1.educgrp#c.c1sess#c.c1sess=2.educgrp#c.c1sess#c.c1sess  // Low vs. Med:  Quad
	contrast educgrp,							// omnibus group diff on intercept
	contrast educgrp#c.c1sess,					// omnibus group diff on linear
	contrast educgrp#c.c1sess#c.c1sess,			// omnibus group diff on quadratic
	margins, at(c.c1sess=(0(1)5) educgrp=(1 2 3)) vsquish  // predictions per session
	marginsplot, name(predicted_educ, replace)		         // plot educ predictions
	predict prededuc			// save fixed-effect predicted outcomes 
corr nm3rt prededuc				// get total r to make r2

 * Export graphs
graph save predicted_age  "C:\Dropbox\14_Psyc930MLM\Download\STATA\Example3_predicted_age.gph", replace
graph save predicted_reas "C:\Dropbox\14_Psyc930MLM\Download\STATA\Example3_predicted_reasoning.gph", replace
graph save predicted_educ "C:\Dropbox\14_Psyc930MLM\Download\STATA\Example3_predicted_education.gph", replace

 * Close log	
 log close

